@@ -8,7 +8,7 @@ package Net::Prometheus;
 use strict;
 use warnings;
 
-our $VERSION = '0.03';
+our $VERSION = '0.04';
 
 use Carp;
 
@@ -19,6 +19,8 @@ use Net::Prometheus::Counter;
 use Net::Prometheus::Summary;
 use Net::Prometheus::Histogram;
 
+use Net::Prometheus::ProcessCollector;
+
 =head1 NAME
 
 C<Net::Prometheus> - export monitoring metrics for F<prometheus>
@@ -70,15 +72,35 @@ own means.
 
 Returns a new C<Net::Prometheus> instance.
 
+Takes the following named arguments:
+
+=over
+
+=item disable_process_collector => BOOL
+
+If present and true, this instance will not load the default process collector
+from L<Net::Prometheus::ProcessCollector>. If absent or false, such a
+collector will be loaded by default. This is usually what you want.
+
+=back
+
 =cut
 
 sub new
 {
    my $class = shift;
+   my %args = @_;
 
-   return bless {
+   my $self = bless {
       collectors => [],
    }, $class;
+
+   if( not $args{disable_process_collector} and
+       my $process_collector = Net::Prometheus::ProcessCollector->new ) {
+      $self->register( $process_collector );
+   }
+
+   return $self;
 }
 
 =head1 METHODS
@@ -184,7 +206,8 @@ sub new_summary
    $histogram = $prometheus->new_histogram( %args )
 
 Constructs a new L<Net::Prometheus::Histogram> using the arguments given
-and registers it with the exporter. The newly-constructed summary is returned.
+and registers it with the exporter. The newly-constructed histogram is
+returned.
 
 =cut
 
@@ -373,7 +396,7 @@ information to be exported.
 
 =item *
 
-Process collector.
+Perl-specific variable collector - arena stats?
 
 =item *
 
