@@ -8,7 +8,7 @@ package Net::Prometheus::Metric;
 use strict;
 use warnings;
 
-our $VERSION = '0.03';
+our $VERSION = '0.04';
 
 use Carp;
 our @CARP_NOT = qw( Net::Prometheus );
@@ -29,15 +29,19 @@ This class provides the basic methods shared by the concrete subclasses,
 
 =item *
 
-L<Net::Prometheus::Gauge>
+L<Net::Prometheus::Gauge> - a snapshot value-reporting metric
 
 =item *
 
-L<Net::Prometheus::Counter>
+L<Net::Prometheus::Counter> - a monotonically-increasing counter metric
 
 =item *
 
-L<Net::Prometheus::Summary>
+L<Net::Prometheus::Summary> - summarise individual numeric observations
+
+=item *
+
+L<Net::Prometheus::Histogram> - count the distribution of numeric observations
 
 =back
 
@@ -56,7 +60,8 @@ L<Net::Prometheus::Summary>
 
 The constructor is not normally used directly by instrumented code. Instead it
 is more common to use one of the C<new_*> methods on the containing
-L<Net::Prometheus> client instance.
+L<Net::Prometheus> client instance so that the new metric is automatically
+registered as a collector, and gets exported by the render method.
 
    $metric = $prometheus->new_counter(
       name => $name,
