@@ -8,9 +8,7 @@ package Net::Prometheus::ProcessCollector;
 use strict;
 use warnings;
 
-our $VERSION = '0.07_001';
-
-use Net::Prometheus::Types qw( MetricSamples Sample );
+our $VERSION = '0.04';
 
 =head1 NAME
 
@@ -48,7 +46,7 @@ pattern based on the value of the C<$^O> variable on the OS concerned.
 
 =head2 new
 
-   $collector = Net::Prometheus::ProcessCollector->new( %args )
+   $collector = Net::Prometheus::ProcessCollector->new( @args )
 
 Attempts to construct a new process collector for the OS named by C<$^O>,
 passing in any extra arguments into the C<new> constructor for the specific
@@ -58,22 +56,6 @@ If no perl module is found under the appropriate file name, C<undef> is
 returned. If any other error occurs while loading or constructing the
 instance, the exception is thrown as normal.
 
-Typically a process exporter should support the following named arguments:
-
-=over
-
-=item prefix => STR
-
-A prefix to prepend on all the exported variable names. If not provided, the
-default should be C<"process">.
-
-=item labels => ARRAY
-
-Additional labels to set on exported variables. If not provided, no extra
-labels will be set.
-
-=back
-
 =cut
 
 sub new
@@ -108,28 +90,4 @@ sub for_OS
    return $pkg->new( @args );
 }
 
-# Methods for subclasses
-
-sub __new
-{
-   my $class = shift;
-   my %args = @_;
-
-   return bless {
-      prefix => $args{prefix} || "process",
-      labels => $args{labels} || [],
-   }, $class;
-}
-
-sub _make_metric
-{
-   my $self = shift;
-   my ( $varname, $value, $type, $help ) = @_;
-
-   my $prefix = $self->{prefix};
-
-   return MetricSamples( "${prefix}_$varname", $type, $help,
-      [ Sample( "${prefix}_$varname", $self->{labels}, $value ) ] );
-}
-
 0x55AA;
